.. bibliography bootstrap Bibliography

References
----------

The bootstrap is a large area with a number of high-quality books. Leading
references include

.. rubric:: References

.. [Chernick] Chernick, M. R. (2011). *Bootstrap methods: A guide for
   practitioners and researchers* (Vol. 619). John Wiley & Sons.

.. [Davidson] Davison, A. C. (1997). *Bootstrap methods and their*
   *application* (Vol. 1). Cambridge university press.

.. [EfronTibshirani] Efron, B., & Tibshirani, R. J. (1994). *An*
   *introduction to the bootstrap* (Vol. 57). CRC press.

.. [PolitisRomanoWolf] Politis, D. N., & Romano, J. P. M. Wolf, 1999.
   *Subsampling*.

Articles used in the creation of this module include

.. [CarpenterBithell] Carpenter, J., & Bithell, J. (2000). "Bootstrap
   confidence intervals: when, which, what? A practical guide for medical
   statisticians." *Statistics in medicine*, 19(9), 1141-1164.

.. [DavidsonMacKinnon] Davidson, R., & MacKinnon, J. G. (2006). "Bootstrap
   methods in econometrics." *Palgrave Handbook of Econometrics*, 1, 812-38.

.. [DiCiccioEfron] DiCiccio, T. J., & Efron, B. (1996). "Bootstrap confidence
   intervals." *Statistical Science*, 189-212.

.. [Efron] Efron, B. (1987). "Better bootstrap confidence intervals."
   *Journal of the American statistical Association*, 82(397), 171-185.
